<?php

/**
 * @file
 * Services API hooks & callbacks
 */


/**
 * Implements hook_services_resource().
 */
function snipcart_services_resources() {

  $resource = array(
    'snipcart_product' => array(
      'operations' => array(
        'retrieve' => array(
          'file' => array(
            'type' => 'inc',
            'module' => 'snipcart',
            'name' => 'snipcart.services'
          ),
          'callback' => '_snipcart_services_product_retrieve',
          'access callback' => '_snipcart_services_access',
          'access arguments append' => TRUE,
          'args' => array(
            array(
              'name' => 'id',
              'optional' => FALSE,
              'source' => array('path' => 0),
              'type' => 'string',
              'description' => 'The product id',
            ),
          ),
        ),
      ),
    ),
  );

  return $resource;

}


/**
 * Snipcart product resource access callback.
 *
 * @param array $args
 *   Services callback arguments
 * @return bool
 *   TRUE if access is granted, FALSE otherwise
 */
function _snipcart_services_product_access($args) {
  $product_id = reset($args);
  if (!$product_id) {
    return FALSE;
  }
  $product = commerce_product_load($product_id);
  if (!$product) {
    return FALSE;
  }
  return commerce_product_access('view', $product);
}


/**
 * Snipcart product resource retrieve callback.
 *
 * The resulting array is intended to be serialized in JSON
 * by the Services API.
 *
 * @param int $product_id
 *   the product id
 * @return array
 *   an associative array of product info
 * @throws \ServicesException
 *   if an unrecoverable error occurs
 */
function _snipcart_services_product_retrieve($product_id){

  $product = commerce_product_load($product_id);

  if(!$product){
    return services_error('Product not found', 404);
  }

  $product_wrapper = entity_metadata_wrapper('commerce_product', $product);

  return array(
    'id' => $product_wrapper->sku->value(),
    'price' => $product_wrapper->commerce_price->amount_decimal->value(),
  );

}
